EXPORTS
	??0CTestScheduler@@QAE@XZ @ 1 NONAME ; CTestScheduler::CTestScheduler(void)
	??1CMsgServerTestUtils@@UAE@XZ @ 2 NONAME ; CMsgServerTestUtils::~CMsgServerTestUtils(void)
	?ChooseDriveL@CMsgServerTestUtils@@QAEXAAVTDriveUnit@@@Z @ 3 NONAME ; void CMsgServerTestUtils::ChooseDriveL(class TDriveUnit &)
	?CleanMessageFolderL@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 4 NONAME ; void CMsgServerTestUtils::CleanMessageFolderL(class TDesC16 const &)
	?Close@CMsgServerTestUtils@@QAEXH@Z @ 5 NONAME ; void CMsgServerTestUtils::Close(int)
	?Complete@CMsgServerTestUtils@@QAEXXZ @ 6 NONAME ; void CMsgServerTestUtils::Complete(void)
	?CorruptIndexFileL@CMsgServerTestUtils@@QAEXHABVTDesC16@@@Z @ 7 NONAME ; void CMsgServerTestUtils::CorruptIndexFileL(int, class TDesC16 const &)
	?CreateDataFilesL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@@Z @ 8 NONAME ABSENT ; public: void __thiscall CMsgServerTestUtils::CreateDataFilesL(class TDesC16 const &,class TDesC16 const &,class TUid)
	?CreateServerL@CMsgServerTestUtils@@QAEPAVCMsvServer@@ABVTDesC16@@@Z @ 9 NONAME ; class CMsvServer * CMsgServerTestUtils::CreateServerL(class TDesC16 const &)
	?End@CMsgServerTestUtils@@QAEXXZ @ 10 NONAME ; void CMsgServerTestUtils::End(void)
	?Error@CTestScheduler@@EBEXH@Z @ 11 NONAME ; void CTestScheduler::Error(int) const
	?FileExists@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 12 NONAME ; void CMsgServerTestUtils::FileExists(class TDesC16 const &)
	?FileMissing@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 13 NONAME ; void CMsgServerTestUtils::FileMissing(class TDesC16 const &)
	?GetConfigL@CMsgServerTestUtils@@QAEXAAVTMsvConfig@@@Z @ 14 NONAME ; void CMsgServerTestUtils::GetConfigL(class TMsvConfig &)
	?IndexSizeL@CMsgServerTestUtils@@QAEHHABVTDesC16@@@Z @ 15 NONAME ; int CMsgServerTestUtils::IndexSizeL(int, class TDesC16 const &)
	?InstallMtmL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@@Z @ 16 NONAME ABSENT ; public: void __thiscall CMsgServerTestUtils::InstallMtmL(class TDesC16 const &,class TDesC16 const &,class TUid)
	?NewL@CMsgServerTestUtils@@SAPAV1@AAVRTest@@@Z @ 17 NONAME ; class CMsgServerTestUtils * CMsgServerTestUtils::NewL(class RTest &)
	?NewLC@CMsgServerTestUtils@@SAPAV1@AAVRTest@@@Z @ 18 NONAME ; class CMsgServerTestUtils * CMsgServerTestUtils::NewLC(class RTest &)
	?Next@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 19 NONAME ; void CMsgServerTestUtils::Next(class TDesC16 const &)
	?ReadInteger@CMsgServerTestUtils@@QAEHABVTDesC16@@AAH@Z @ 20 NONAME ; int CMsgServerTestUtils::ReadInteger(class TDesC16 const &, int &)
	?RemoveIndexFile@CMsgServerTestUtils@@QAEXH@Z @ 21 NONAME ; void CMsgServerTestUtils::RemoveIndexFile(int)
	?RemoveMailFolderL@CMsgServerTestUtils@@QAEXH@Z @ 22 NONAME ; void CMsgServerTestUtils::RemoveMailFolderL(int)
	?SetConfigL@CMsgServerTestUtils@@QAEXAAVTMsvConfig@@@Z @ 23 NONAME ; void CMsgServerTestUtils::SetConfigL(class TMsvConfig &)
	?SetDebugL@CMsgServerTestUtils@@QAEXH@Z @ 24 NONAME ; void CMsgServerTestUtils::SetDebugL(int)
	?SetDriveL@CMsgServerTestUtils@@QAEXHH@Z @ 25 NONAME ; void CMsgServerTestUtils::SetDriveL(int, int)
	?SetupL@CMsgServerTestUtils@@QAEXXZ @ 26 NONAME ; void CMsgServerTestUtils::SetupL(void)
	?Start@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 27 NONAME ; void CMsgServerTestUtils::Start(class TDesC16 const &)
	?WaitForKeyL@CMsgServerTestUtils@@QAEHVTTimeIntervalMicroSeconds32@@PAW4TKeyCode@@@Z @ 28 NONAME ; int CMsgServerTestUtils::WaitForKeyL(class TTimeIntervalMicroSeconds32, enum TKeyCode *)
	?WaitForServerClose@CMsgServerTestUtils@@QAEXXZ @ 29 NONAME ; void CMsgServerTestUtils::WaitForServerClose(void)
	?CreateDataFilesL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@00@Z @ 30 NONAME ; void CMsgServerTestUtils::CreateDataFilesL(class TDesC16 const &, class TDesC16 const &, class TUid, class TDesC16 const &, class TDesC16 const &)
	?InstallMtmL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@00@Z @ 31 NONAME ; void CMsgServerTestUtils::InstallMtmL(class TDesC16 const &, class TDesC16 const &, class TUid, class TDesC16 const &, class TDesC16 const &)
	_E32Dll=__E32Dll	; Entry point for emulation

